<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>AIAssistantWidget</name>
    <message>
        <source>Explain</source>
        <translation>Explicar</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Traducir</translation>
    </message>
    <message>
        <source>Ask AI</source>
        <translation>Preguntar a AI</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation>Resumen</translation>
    </message>
</context>
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Prema na icona da bandexa
ou prema de novo o atallo para deixar de gravar</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Non xire a pantalla durante a gravación</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravando</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Pechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar ao portapapeis (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Fallou o gardado. Gardao no seu directorio persoal.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla finalizada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleccionar-área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Portapapeis</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Gardando a captura de pantalla, por favor agarde...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Como o efecto xanela está desactivado durante o proceso, a gravación debe deterse</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desprazamento</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixar capturas de pantalla</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir cartafol</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Captura finalizada e copiar ao portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localización especificada</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Establece un camiño ao gardar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Cambia o camiño ao gardar</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imaxes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Fixar capturas de pantalla</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Gravando</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Gravación finalizada</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir cartafol</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Cada consulta</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Localización especificada</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecciona unha localización ao gardar</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Actualiza a localización ao gardar</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Imaxes</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>A captura de pantalla comezará en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Obtén axuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Produciuse un erro ao facer unha captura de pantalla continua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Chegou á parte inferior da área de desprazamento</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Alcanzou a lonxitude máxima</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>axustar a área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Despraza a roda do rato ou fai clic para facer unha captura de pantalla de desprazamento</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Reduce a velocidade de desprazamento</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Área non válida, fai clic para</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Insira o texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Comezar/Captura de pantalla</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Saír/Gardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Axuste do tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de pantalla da xanela</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Retrasar a captura de pantalla</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura de pantalla enteira</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Gardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Liña</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Lapis</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumente a altura cara arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumente a altura cara abaixo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumenta o ancho á esquerda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumenta o ancho á dereita</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Reducir a altura</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Reducir a altura cara abaixo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Reduce o ancho á esquerda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Reduce a anchura á dereita</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atallos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tecla</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Iniciar gravación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Iniciar/Gravación</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Captura de desprazamento</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fixar capturas de pantalla</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Iniciar OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Iniciar captura de desprazamento</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Frecha</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectángulo
Manteña premida a tecla Maiúsculas para debuxar un cadrado</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipse
Manteña premida a tecla Maiúsculas para debuxar un círculo</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pincel
Manteña premida a tecla Maiúsculas para debuxar unha liña recta</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Axustar a intensidade do desenfoque (Desprácese para axustalo)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Axustar o tamaño do pincel (Desprácese para axustalo)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Axustar o tamaño do texto (Desprácese para axustalo)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Amosar tecla (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Agochar tecla (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Amosar tecla (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Acender a cámara (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Apagar a cámara (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuracións</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Configuración (F3)</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Micrófono</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio do sistema</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar punteiro</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Amosar Premer</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Gardar en</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Liña (L)
Manteña premida Maiúsculas para debuxar unha liña vertical ou horizontal</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Frecha (X)
Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizontal</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Lapis (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Desenfoque (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Texto (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Captura de desprazamento (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extraer texto (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Fixar capturas de pantalla (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Desfacer (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Gravar</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Cambia o camiño ao gardar</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efectos do borde</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ningún</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Sombra</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Ferramentas xeométricas (R)
Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Gardar no local</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Gardar en %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Localización especificada</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Actualiza a localización ao gardar</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Selecciona unha localización ao gardar</translation>
    </message>
    <message>
        <source>AI Screenshot (A)</source>
        <translation>Captura de pantalla AI (A)</translation>
    </message>
    <message>
        <source>Save to Desktop</source>
        <translation>Gardar no escritorio</translation>
    </message>
    <message>
        <source>Save to Pictures</source>
        <translation>Gardar en imaxes</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Pechar (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Copiar ao portapapeis (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Axusta a área de gravación dentro de %1*%2 para obter un mellor efecto de vídeo</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Actualmente non se admite a gravación da pantalla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Saír</translation>
    </message>
</context>
</TS>
